PrefabFiles = {
}

Assets = {
    Asset( "IMAGE", "images/saveslot_portraits/wolf.tex" ),
    Asset( "ATLAS", "images/saveslot_portraits/wolf.xml" ),

    Asset( "IMAGE", "images/selectscreen_portraits/wolf.tex" ),
    Asset( "ATLAS", "images/selectscreen_portraits/wolf.xml" ),

    Asset( "IMAGE", "bigportraits/wolf.tex" ),
    Asset( "ATLAS", "bigportraits/wolf.xml" ),
	
	Asset( "IMAGE", "images/map_icons/wolf.tex" ),
	Asset( "ATLAS", "images/map_icons/wolf.xml" ),

}

local require = GLOBAL.require
local Vector3 = GLOBAL.Vector3
local GetWorld = GLOBAL.GetWorld
local GetPlayer = GLOBAL.GetPlayer
local SpawnPrefab = GLOBAL.SpawnPrefab

-- The character select screen lines
GLOBAL.STRINGS.CHARACTER_TITLES.wolf = "The lone wolf"
GLOBAL.STRINGS.CHARACTER_NAMES.wolf = "wolf"
GLOBAL.STRINGS.CHARACTER_DESCRIPTIONS.wolf = "*Eats meats and bones only\n*Hates rain\n*Loves tracking and digging"
GLOBAL.STRINGS.CHARACTER_QUOTES.wolf = "\"Rawr?\""

-- Custom speech strings
GLOBAL.STRINGS.CHARACTERS.WOLF = require "speech_wolf"

-- Let the game know character is male, female, or robot
table.insert(GLOBAL.CHARACTER_GENDERS.MALE, "wolf")


local function onUnbury(inst, worker)
	if inst and inst.components.workable then
		local oldFun = inst.components.workable.OldOnFinish
		if oldFun then
			oldFun(inst, worker)
		end
	end
	GetPlayer():PushEvent("unburrying")
end

local function overrideGrave(inst)
	if inst and inst.components.workable then
		inst.components.workable.OldOnFinish = inst.components.workable.onfinish
		inst.components.workable.onfinish = onUnbury
	end
end

AddPrefabPostInit("mound", overrideGrave)

local function onInvestigateDirt(inst, doer)
	if inst and inst.components.activatable then
		local oldFun = inst.components.activatable.OldOnActivate
		if oldFun then
			oldFun(inst, doer)
		end
	end
	GetPlayer():PushEvent("tracking")
end

local function overrideDirt(inst)
	if inst and inst.components.activatable then
		inst.components.activatable.OldOnActivate = inst.components.activatable.OnActivate
		inst.components.activatable.OnActivate = onInvestigateDirt
	end
end

AddPrefabPostInit("dirtpile", overrideDirt)

-- Edible bones
local function makeBonesEdible(inst)
	inst:AddComponent("edible")
	inst.components.edible.ismeat = true
	inst.components.edible.foodtype = "BONES"
	inst.components.edible.healthvalue = TUNING.HEALING_SMALL -- TUNING
	inst.components.edible.sanityvalue = TUNING.SANITY_SMALL -- TUNING
	if TheSim then
		if TheSim:IsDLCEnabled(1) then
			inst.components.edible.hungervalue = TUNING.CALORIES_MED -- TUNING
		else
			inst.components.edible.hungervalue = TUNING.CALORIES_SMALL -- TUNING
		end
	else
		inst.components.edible.hungervalue = TUNING.CALORIES_SMALL -- TUNING
	end
end

-- Edible teeth
local function makeTeethEdible(inst)
	inst:AddComponent("edible")
	inst.components.edible.ismeat = true
	inst.components.edible.foodtype = "TEETH"
	inst.components.edible.healthvalue = TUNING.HEALING_SMALL -- TUNING
	inst.components.edible.hungervalue = TUNING.CALORIES_MED -- TUNING
	inst.components.edible.sanityvalue = TUNING.SANITY_SMALL -- TUNING
end

AddPrefabPostInit("boneshard", makeBonesEdible)
AddPrefabPostInit("houndstooth", makeTeethEdible) -- Replacement

table.insert(PrefabFiles,"wolf")

-- make monster food and raw meat harmless to the wolf
local function makeWolfFood(inst)
	if inst and inst.components.edible then
		if GetPlayer().prefab == "wolf" then
			if inst.components.edible.healthvalue and inst.components.edible.healthvalue < 0 then
				inst.components.edible.healthvalue = 0
			end
			if inst.components.edible.sanityvalue and inst.components.edible.sanityvalue < 0 then
				inst.components.edible.sanityvalue = 0
			end
		end
	end
end

AddPrefabPostInit("meat", makeWolfFood)
AddPrefabPostInit("smallmeat", makeWolfFood)
AddPrefabPostInit("monstermeat", makeWolfFood)
AddPrefabPostInit("cookedmonstermeat", makeWolfFood)
AddPrefabPostInit("monstermeat_dried", makeWolfFood)
AddPrefabPostInit("monsterlasagna", makeWolfFood)

-- Minimap
AddMinimapAtlas("images/map_icons/wolf.xml")
AddModCharacter("wolf")

