
local MakePlayerCharacter = require "prefabs/player_common"

local assets = {

        Asset( "ANIM", "anim/player_basic.zip" ),
        Asset( "ANIM", "anim/player_idles_shiver.zip" ),
        Asset( "ANIM", "anim/player_actions.zip" ),
        Asset( "ANIM", "anim/player_actions_axe.zip" ),
        Asset( "ANIM", "anim/player_actions_pickaxe.zip" ),
        Asset( "ANIM", "anim/player_actions_shovel.zip" ),
        Asset( "ANIM", "anim/player_actions_blowdart.zip" ),
        Asset( "ANIM", "anim/player_actions_eat.zip" ),
        Asset( "ANIM", "anim/player_actions_item.zip" ),
        Asset( "ANIM", "anim/player_actions_uniqueitem.zip" ),
        Asset( "ANIM", "anim/player_actions_bugnet.zip" ),
        Asset( "ANIM", "anim/player_actions_fishing.zip" ),
        Asset( "ANIM", "anim/player_actions_boomerang.zip" ),
        Asset( "ANIM", "anim/player_bush_hat.zip" ),
        Asset( "ANIM", "anim/player_attacks.zip" ),
        Asset( "ANIM", "anim/player_idles.zip" ),
        Asset( "ANIM", "anim/player_rebirth.zip" ),
        Asset( "ANIM", "anim/player_jump.zip" ),
        Asset( "ANIM", "anim/player_amulet_resurrect.zip" ),
        Asset( "ANIM", "anim/player_teleport.zip" ),
        Asset( "ANIM", "anim/wilson_fx.zip" ),
        Asset( "ANIM", "anim/player_one_man_band.zip" ),
        Asset( "ANIM", "anim/shadow_hands.zip" ),
        Asset( "SOUND", "sound/sfx.fsb" ),
        Asset( "SOUND", "sound/wilson.fsb" ),
        Asset( "ANIM", "anim/beard.zip" ),

        Asset( "ANIM", "anim/wolf.zip" ),
}

local prefabs = {}

local start_inv_dlc = {
	"monstermeat",
	"monstermeat",
	"boneshard",
	"boneshard",
}
local start_inv = {
	"monstermeat",
	"monstermeat",
	"houndstooth",
	"houndstooth",
}

local function trackingHappiness(inst)
	if inst and inst.components.sanity then
		inst.components.sanity:DoDelta(TUNING.SANITY_TINY) -- TUNING
	end
end

local function unburryingHappiness(inst)
	if inst and inst.components.sanity then
		inst.components.sanity:DoDelta(TUNING.SANITY_SMALL * 2) -- TUNING
	end
end

local function sanityfn(inst)
	local delta = 0
	local mitigates_rain = false
	
	if not inst then
		return 0
	end
	if TheSim:IsDLCEnabled(1) or SaveGameIndex:IsModeShipwrecked() then
		if inst and inst.components.sanity then
			delta = inst.components.sanity:GetMoistureDelta()
		end
	else
		if inst.components.inventory and inst.components.inventory.equipslots then
			for k,v in pairs (inst.components.inventory.equipslots) do
				if v.components.dapperness then
					if v.components.dapperness.mitigates_rain then
						mitigates_rain = true
					end
				end		
			end
		end
		
		if GetSeasonManager() and GetSeasonManager():IsRaining() and not mitigates_rain then
			delta = -TUNING.DAPPERNESS_MED*1.5*GetSeasonManager():GetPrecipitationRate()
		end
	end
    
    return delta * 0.5 -- TUNING
end

local fn = function(inst)
	
	-- choose which sounds this character will play
	inst.soundsname = "wolfgang"

	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "wolf.tex" )
	
	-- Stats	
	inst.components.health:SetMaxHealth(160)
	inst.components.hunger:SetMax(180)
	inst.components.sanity:SetMax(140)
	
	inst.components.locomotor.walkspeed = (TUNING.WILSON_WALK_SPEED * 1.2)
	inst.components.locomotor.runspeed = (TUNING.WILSON_RUN_SPEED * 1.2)
	
	inst.components.sanity.night_drain_mult = 0.8
	inst.components.sanity.custom_rate_fn = sanityfn
	
	inst.components.eater.stale_hunger = 1
	inst.components.eater.stale_health = 1
	inst.components.eater:SetCarnivore(true)
	
	inst.components.temperature.inherentinsulation = TUNING.INSULATION_MED -- TUNING
	
	inst:ListenForEvent("tracking", trackingHappiness)
	inst:ListenForEvent("unburrying", unburryingHappiness)
	
	-- differences between RoG expansion and vanilla game go here
	if TheSim:IsDLCEnabled(1) or SaveGameIndex:IsModeShipwrecked() then
		if inst.components.moisture then
			inst.components.moisture.maxMoistureRate = inst.components.moisture.maxMoistureRate * 0.8 -- TUNING
			inst.components.moisture.maxPlayerTempDrying = inst.components.moisture.maxPlayerTempDrying * 0.8 -- TUNING
			inst.components.moisture.maxDryingRate = inst.components.moisture.maxDryingRate * 0.8 -- TUNING
		end
		if inst.components.eater.foodprefs then
			table.insert(inst.components.eater.foodprefs, "BONES")
		end
		if inst.components.eater.ablefoods then
			table.insert(inst.components.eater.ablefoods, "BONES")
		end
	else
		if inst.components.eater.foodprefs then
			table.insert(inst.components.eater.foodprefs, "TEETH")
		end
		if inst.components.eater.ablefoods then
			table.insert(inst.components.eater.ablefoods, "TEETH")
		end
	end
end

if TheSim:IsDLCEnabled(1) or SaveGameIndex:IsModeShipwrecked() then
	return MakePlayerCharacter("wolf", prefabs, assets, fn, start_inv_dlc)
else
	return MakePlayerCharacter("wolf", prefabs, assets, fn, start_inv)
end
